pub struct Struct {
pub name: &'static str,
pub fields: Vec<(&'static str, Option<Value>)>,
}Expand description
Representation of differences between two structs of a common type.
Fields
name: &'static strName of the struct: type name for standalone struct, or variant name for enum struct-variants.
fields: Vec<(&'static str, Option<Value>)>Fields of the struct in the order they were visited. Fields visited
using skip_field have the value None, everything else is Some.